# Plot examples

```{note}
  Not all example plots are from the same model!
```

## Temperature and density history

![Temperature and density history example](png/T-rho-hist.png)

## Surface elevation history

![Surface elevation history example](png/elev-hist.png)

## Cooling history and predicted ages

![Cooling history and predicted ages example](png/cooling-hist.png)

## Ages at the model surface through time

![Ages at the model surface through time example](png/past-ages.png)